Tutorials(Beginner)
-------------------

This document lists some beginner's tutorials. These tutorials are aimed at people who are starting to learn how to use PyDy.
These tutorials are in the form of IPython notebooks.

Tutorials:

  - `Mass Spring Damper example`_
  - `Inverted pendulum model of a standing human`_

.. _`Mass Spring Damper example`: http://nbviewer.ipython.org/github/pydy/pydy/blob/master/examples/mass_spring_damper/mass_spring_damper.ipynb
.. _`Inverted pendulum model of a standing human`: http://nbviewer.ipython.org/github/pydy/pydy-tutorial-human-standing/blob/online-read/notebooks/n00_python_intro.ipynb

